summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPaul E. McKenney <paulmck@kernel.org>2024-01-21 07:11:45 -0800
committerPaul E. McKenney <paulmck@kernel.org>2024-01-22 12:20:09 -0800
commit4dcf56821478779143757d5cc6c73a99d62f23f3 (patch)
treed8fce43b2715246b66fea6203d44fdb74c856f60
parent042f1792f4416b0f18d228d380ff85b29ab7a7f5 (diff)
downloadperfbook-4dcf56821478779143757d5cc6c73a99d62f23f3.tar.gz
CodeSamples/cpu: Make perftemporal.sh collect coe-nvals data
Signed-off-by: Paul E. McKenney <paulmck@kernel.org>
-rw-r--r--CodeSamples/cpu/perftemporal.sh5
1 files changed, 4 insertions, 1 deletions
diff --git a/CodeSamples/cpu/perftemporal.sh b/CodeSamples/cpu/perftemporal.sh
index 484b35d6..da72e17f 100644
--- a/CodeSamples/cpu/perftemporal.sh
+++ b/CodeSamples/cpu/perftemporal.sh
@@ -1,6 +1,7 @@
#!/bin/bash
#
# Collect temporal data using coe.sh, fre.sh, and rfe.sh.
#
# Usage: bash perftemporal.sh tag [ [ reps ] nthreads ]
#
@@ -61,6 +62,8 @@ echo $0: $reps repetitions on $nthreads CPUs
echo " " Output to $tag
lscpu > $tag/lscpu.out
+./temporal --coe --nthreads $nthreads > $tag/coe-nvals.out
+bash coereduce.sh < $tag/coe-nvals.out > $tag/coe-nvals.dat
for pgm in coe fre rfe
do
for ((i=0;i<reps;i++))
@@ -1,6 +1,7 @@
#!/bin/bash
#
-# Collect temporal data using coe.sh, fre.sh, and rfe.sh.
+# Collect temporal data using coe.sh, fre.sh, rfe.sh, and
+# "./temporal --coe --nthreads".
#
# Usage: bash perftemporal.sh tag [ [ reps ] nthreads ]